﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using Silanis.ESL.SDK;
using Silanis.ESL.SDK.Builder;

namespace esl
{
    class CarLoanApplication
    {
        private static string API_KEY = "";
        private static string API_URL = ""; //e.g. https://sandbox.esignlive.com/api
        public static void start()
        {
            EslClient eslClient = new EslClient(API_KEY, API_URL);

            DocumentPackage documentPackage = PackageBuilder.NewPackageNamed("Car Loan Application")
                .WithSigner(SignerBuilder.NewSignerWithEmail("mail30@mailinator.com")
                        .WithFirstName("John")
                        .WithLastName("Smith")
                        .WithCustomId("Signer1")
                        .WithSMSSentTo("418-555-5585")
                        .WithAttachmentRequirement(AttachmentRequirementBuilder.NewAttachmentRequirementWithName("Driver license")
                            .WithDescription("Please upload a copy of your driver license.")
                            .IsRequiredAttachment()
                            .Build()))
                .WithSigner(SignerBuilder.NewSignerWithEmail("mail32@mailinator.com")
                        .WithFirstName("Patty")
                        .WithLastName("Galant")
                        .WithCustomId("Signer2")
                        .ChallengedWithQuestions(ChallengeBuilder.FirstQuestion("What's 1+1?")
                            .Answer("2")))
                .WithDocument(DocumentBuilder.NewDocumentNamed("Car Loan Agreement")
                        .FromFile("../4B-CarLoan.pdf")
                        .EnableExtraction()
                        .WithSignature(SignatureBuilder.SignatureFor("mail30@mailinator.com")
                                .WithName("applicant_signature")
                                .WithPositionExtracted()
                                .WithField(FieldBuilder.SignatureDate()
                                        .WithName("Date")
                                        .WithPositionExtracted())
                                .WithField(FieldBuilder.CheckBox()
                                        .WithName("agree")
                                        .WithPositionExtracted())
                                .WithField(FieldBuilder.RadioButton("radioGroup")
                                        .WithName("radio1")
                                        .WithPositionExtracted()
                                        .WithValue("X"))
                                .WithField(FieldBuilder.RadioButton("radioGroup")
                                        .WithName("radio2")
                                        .WithPositionExtracted())
                                .WithField(FieldBuilder.RadioButton("radioGroup")
                                        .WithName("radio3")
                                        .WithPositionExtracted()))
                        .WithSignature(SignatureBuilder.SignatureFor("mail32@mailinator.com")
                                .WithName("coapplicant_signature")
                                .WithPositionExtracted())
                        .WithInjectedField(FieldBuilder.TextField()
                                .WithName("amount")
                                .WithValue("50000"))
                        .WithInjectedField(FieldBuilder.TextField()
                                .WithName("applicant_name")
                                .WithValue("John Smith"))
                        .WithInjectedField(FieldBuilder.TextField()
                                .WithName("applicant_email")
                                .WithValue("mail30@mailinator.com"))
                        .WithInjectedField(FieldBuilder.TextField()
                                .WithName("coapplicant_email")
                                .WithValue("mail32@mailinator.com"))
                        .WithInjectedField(FieldBuilder.TextField()
                                .WithName("coapplicant_name")
                                .WithValue("Patty Galant"))
                        .WithInjectedField(FieldBuilder.TextField()
                                .WithName("radio5")
                                .WithValue("X"))
                        )
                .Build();

            PackageId packageId = eslClient.CreateAndSendPackage(documentPackage);
        }
    }
}
